import java.io.*;
import java.net.*;

public class NewEmailSender {

	public static void main (String [] args) throws Exception {

		String replyFromUser;
		String replyFromServer; 
		String commandToServer; 

		Socket clientSocket = null;
		DataOutputStream outToServer = null;
		BufferedReader inFromServer = null;

		if (args.length<3) {
		    System.out.println("use: NewEmailSender <smtp-server> <port> <sender-email>");
			System.exit(0);
		}

		int port = Integer.parseInt(args[1]);

		// Establish a TCP connection with the mail server
		try {
			clientSocket = new Socket(args[0], port);
			System.out.println("Client on port " + clientSocket.getLocalPort());
			System.out.println("Client connected to port " + clientSocket.getPort());

			outToServer = new DataOutputStream(clientSocket.getOutputStream()); 
			inFromServer = new BufferedReader(new InputStreamReader(clientSocket.getInputStream())); 

		} catch (UnknownHostException e) {
			System.err.println("Don't know about host");
			System.exit(1);
		} catch (IOException e) {
			System.err.println("Couldn't get I/O for the connection to: localhost");
			System.exit(1);
		}


		// prepare to read from the input
		BufferedReader inFromUser = new BufferedReader(new InputStreamReader(System.in)); 

		// br = inFromServer

		// Get a reference to the socket's output stream.
		//OutputStream os = socket.getOutputStream();

		// Read greeting from the server.
		replyFromServer = inFromServer.readLine();
		if (!replyFromServer.startsWith("220")) {
			throw new Exception("220 reply not received from server.");
		}

		// Send HELO command and get server response
		outToServer.writeBytes("HELO mySMTP.it\n");
		replyFromServer = inFromServer.readLine();
		if (!replyFromServer.startsWith("250")) {
			throw new Exception ("250 reply not received from server.");
		}

		// Send MAIL FROM command
		outToServer.writeBytes("MAIL FROM: <" + args[2] + ">\n");	
		replyFromServer = inFromServer.readLine();
		if (!replyFromServer.startsWith("250")) {
			throw new Exception ("250 reply not received from server.");
		}

		// Send RCPT TO command.
		System.out.println("Email to: ");
		replyFromUser = inFromUser.readLine(); 		//read the input
		outToServer.writeBytes("RCPT TO: <" + replyFromUser + ">\n");	
		replyFromServer = inFromServer.readLine();
		if (!replyFromServer.startsWith("250")) {
			throw new Exception ("250 reply not received from server.");
		}

		outToServer.writeBytes("DATA\n");	
		replyFromServer = inFromServer.readLine();
		if (!replyFromServer.startsWith("354")) {
			throw new Exception ("354 reply not received from server.");
		}

		System.out.println("Email subject: ");
		replyFromUser = inFromUser.readLine(); 		//read the input
		outToServer.writeBytes("Subject: " + replyFromUser + "\n\n");

		System.out.println("Message text (end with a line starting with .): ");
		Boolean goOn = true;
		while(goOn){
			replyFromUser = inFromUser.readLine(); 		//read the input
			if (replyFromUser.startsWith(".")){
				goOn = false;
			}
			else {
				outToServer.writeBytes(replyFromUser + "\n");
			}
		}
		outToServer.writeBytes("\n.\n");
		replyFromServer = inFromServer.readLine();
		if (!replyFromServer.startsWith("250")) {
			throw new Exception ("250 reply not received from server.");
		}

		outToServer.writeBytes("QUIT\n");	
		replyFromServer = inFromServer.readLine();
		if (!replyFromServer.startsWith("221")) {
			throw new Exception ("221 reply not received from server.");
		}
		else {
			System.out.println(replyFromServer);
		}
	}
}

